<?php

require_once 'User.php';

require_once 'data/MySQLBackEndDataModel.php';

//backend db <> user model
class BEUserModel 
{
    private $m_DataAccess;
    
    public function __construct()
    {
        $this->m_DataAccess = new MySQLBackEndDataModel();
    }
    
    public function __destruct()
    {
        // not doing anything at the moment
    }
            
    //get user given username (used for populating the edit form,
    //also for showing the user's name on the welcome page and determining 
    //authorization for backend functions
    public function fetchUser($userName)
    {
        $user = new User();
        $this->m_DataAccess->connectToDB();
        $userRecord = $this->m_DataAccess->findUser($userName);
        $user->setUserName($userRecord['username']);
        $user->setFirstName($userRecord['first_name']);
        $user->setLastName($userRecord['last_name']);
        $user->setEmail($userRecord['email']);
        $user->setAdmin($userRecord['is_admin']);
        $user->setEditor($userRecord['is_editor']);
        $user->setAuthor($userRecord['is_author']);
        return $user;
    }
    
    //get all users (for the display table)
    public function fetchAllUsers()
    {
        $usersArray = array();
        $this->m_DataAccess->connectToDB();
        $this->m_DataAccess->selectUsers();
        while($row = $this->m_DataAccess->fetchUsers())
        {
            $currentUser = new User();
            $currentUser->setUserName($row['username']);
            $currentUser->setFirstName($row['first_name']);
            $currentUser->setLastName($row['last_name']);
            $currentUser->setEmail($row['email']);
            $currentUser->setAdmin($row['is_admin']);
            $currentUser->setEditor($row['is_editor']);
            $currentUser->setAuthor($row['is_author']);
            $currentUser->setCreate_by($row['create_by']);
            $currentUser->setCreate_dt($row['create_dt']);
            $currentUser->setMod_by($row['mod_by']);
            $currentUser->setMod_dt($row['mod_dt']);
            $usersArray[] = $currentUser;
        }
        return $usersArray;
    }
    
    //generate a unique short string to use as our salt
    //http://stackoverflow.com/questions/3954599/generate-random-string-from-4-to-8-characters-in-php
    private function unique_id($l = 8) {
    return substr(md5(uniqid(mt_rand(), true)), 0, $l);
    }
    
    //insert a new user record
    public function insertUser($who, $username,$password,$firstname,$lastname,$email,$isAdmin,$isEditor,$isAuthor)
    {
        
        $salttosave = $this->unique_id();
        //now hash the supplied password
        $cryptbits = explode("$", crypt($password, "$6\$rounds=1000$" . $salttosave .  "$")) ;
        $hashedpwdtosave = $cryptbits[4];
        
        $newUser = new User();
        $newUser->setUserName($username);
        $newUser->setPwd($hashedpwdtosave);
        $newUser->setSalt($salttosave);
        $newUser->setFirstName($firstname);
        $newUser->setLastName($lastname);
        $newUser->setEmail($email);
        $newUser->setAdmin($isAdmin);
        $newUser->setEditor($isEditor);
        $newUser->setAuthor($isAuthor);
        
        //save the new user to the DB
        $this->m_DataAccess->saveNewUser($who,$newUser);
        return;
    }
    
    //edit user record
    public function editUser($who, $origuname, $username,$password,$firstname,$lastname,$email,$isAdmin,$isEditor,$isAuthor)
    {
        $editUser = new User();
        
        if ($password != "")//if they're not saving a new password, skip this
        {
        $salttosave = $this->unique_id();
        //now hash the supplied password
        $cryptbits = explode("$", crypt($password, "$6\$rounds=1000$" . $salttosave .  "$")) ;
        $hashedpwdtosave = $cryptbits[4];
        $editUser->setPwd($hashedpwdtosave);
        $editUser->setSalt($salttosave);
        }     
        
        $editUser->setUserName($username);
        $editUser->setFirstName($firstname);
        $editUser->setLastName($lastname);
        $editUser->setEmail($email);
        $editUser->setAdmin($isAdmin);
        $editUser->setEditor($isEditor);
        $editUser->setAuthor($isAuthor);
        
        //save the new user to the DB
        $this->m_DataAccess->updateUser($who, $origuname, $editUser);
        return;
    }
    
}

?>
